==> 2.0.3.tar.gz: nci2/nci2/config.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
############################################
#                        _   ___           #
#            _ _    __  (_) |_  )          #
#           | ' \  / _| | |  / /           #
#           |_||_| \__| |_| /___|          #
#                                          #
############################################
# nci2: blog generator for neocities. it's #
# is an improved version of the old nci    #
# web script by nokoru <nokoru@disroot.org>#
#                                          #
# license: unlicense                       #
############################################
from .format import *

# Check if the nci2 configuration file is OK
def cfg_file_ok():
    try:
        open(".nci2/nci2.conf").close()
    except FileNotFoundError:
        return False
    return True

# Read configuration file
def read_cfg_file():
    if not cfg_file_ok():
        printf("{red}[{b}error{r}{red}]{r} Couldn't read nci2 configuration (nci2.conf doesn't exist?)")
        exit(1)

    raw_cfg_file = open(".nci2/nci2.conf").readlines()
    nci2_cfg = {}
    for line in raw_cfg_file:
        if line.find("#") == 0 or line.strip() == "":
            continue
        tmp_dict = line.split("=")
        key = tmp_dict[0]
        if len(tmp_dict) > 2:
            i=0
            value = ""
            for w in tmp_dict:
                if i == 0:
                    i+=1
                    continue
                elif i == len(tmp_dict)-1:
                    value += w
                else:
                    value += w + "="
                i+=1
        else:
            value = tmp_dict[1]

        nci2_cfg[key] = value.replace("\n", "")
    return nci2_cfg

# Add/set an option in nci2 configuration
def set_cfg(key, value):
    if not cfg_file_ok():
        printf("{red}[{b}error{r}{red}]{r} Couldn't read nci2 configuration (nci2.conf doesn't exist?)")
        exit(1)

    raw_cfg_file = open(".nci2/nci2.conf").read()
    cfg = raw_cfg_file.split("\n")
    new_raw_cfg_file = ""
    i=0
    for line in cfg:
        if line.find("#") == 0 or line.strip() == "":
            new_raw_cfg_file += line + "\n"
            i+=1
            continue
        tmp_dict = line.split("=")
        tmp_key = tmp_dict[0]
        if tmp_key == key:
            cfg[i] = key + "=" + value
            new_raw_cfg_file += cfg[i] + "\n"
        else:
            new_raw_cfg_file += line + "\n"
            i+=1
            continue

    open(".nci2/nci2.conf","w").write(new_raw_cfg_file)

==> 2.0.5.tar.gz: nci2/nci2/config.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
############################################
#                        _   ___           #
#            _ _    __  (_) |_  )          #
#           | ' \  / _| | |  / /           #
#           |_||_| \__| |_| /___|          #
#                                          #
############################################
# nci2: blog generator for neocities. it's #
# is an improved version of the old nci    #
# web script by nokoru <nokoru@disroot.org>#
#                                          #
# license: unlicense                       #
############################################
from .format import *

# Check if the nci2 configuration file is OK
def cfg_file_ok():
    try:
        open(".nci2/nci2.conf").close()
    except FileNotFoundError:
        return False
    return True

# Read configuration file
def read_cfg_file():
    if not cfg_file_ok():
        printf("{red}[{b}error{r}{red}]{r} Couldn't read nci2 configuration (nci2.conf doesn't exist?)")
        exit(1)

    raw_cfg_file = open(".nci2/nci2.conf").readlines()
    nci2_cfg = {}
    for line in raw_cfg_file:
        if line.find("#") == 0 or line.strip() == "":
            continue
        tmp_dict = line.split("=")
        key = tmp_dict[0]
        if len(tmp_dict) > 2:
            i=0
            value = ""
            for w in tmp_dict:
                if i == 0:
                    i+=1
                    continue
                elif i == len(tmp_dict)-1:
                    value += w
                else:
                    value += w + "="
                i+=1
        else:
            value = tmp_dict[1]

        nci2_cfg[key] = value.replace("\n", "")
    return nci2_cfg

# Add/set an option in nci2 configuration
def set_cfg(key, value):
    if not cfg_file_ok():
        printf("{red}[{b}error{r}{red}]{r} Couldn't read nci2 configuration (nci2.conf doesn't exist?)")
        exit(1)

    raw_cfg_file = open(".nci2/nci2.conf").read()
    cfg = raw_cfg_file.split("\n")
    max_lines = len(cfg)
    new_raw_cfg_file = ""
    i=0
    for line in cfg:
        nl = "\n" if i+1 != max_lines else ""
        if line.find("#") == 0 or line.strip() == "":
            new_raw_cfg_file += line + nl
            i+=1
            continue
        tmp_dict = line.split("=")
        tmp_key = tmp_dict[0]
        if tmp_key == key:
            cfg[i] = key + "=" + value
            new_raw_cfg_file += cfg[i] + nl
        else:
            new_raw_cfg_file += line + nl
        i+=1
    open(".nci2/nci2.conf","w").write(new_raw_cfg_file)
